Acknowledgement
===============

**naturf** is actively developed as an open-source project as a part of the `Integrated Multisector Multiscale Modeling (IM3) <https://im3.pnnl.gov/>`_ project.  IM3 is a multi-institutional effort led by Pacific Northwest National Laboratory and supported by the `U.S. Department of Energy’s Office of Science <https://www.energy.gov/science/office-science>`_ as part of research in `MultiSector Dynamics <https://climatemodeling.science.energy.gov/program/multisector-dynamics>`_, Earth and Environmental Systems Modeling Program.
